==> woosignal_stripe-0.1.0.tar.gz: lib/woosignal_stripe.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class FlutterStripePayment {
  static const MethodChannel _channel = const MethodChannel('woosignal_stripe');

  static Future<void> setStripeSettings(
      {String applePayMerchantIdentifier,
      String stripeAccount,
      bool liveMode, bool useShopifyGateway}) async {
    Map<String, Object> args = <String, dynamic>{
      "stripePublishableKey": (liveMode == true
          ? "pk_live_IyS4Vt86L49jITSfaUShumzi"
          : "pk_test_0jMmpBntJ6UkizPkfiB8ZJxH")
    };
    if (useShopifyGateway == true) {
      args = <String, dynamic>{
        "stripePublishableKey": (liveMode == true
            ? "pk_live_51HkpeZA0ee3CqG3ORUQuHfGW35nfCRi6SVP77RMjYu4IsWwRMjhHrNKrqD6Q47jETYLH3CtXqk4Px8SBVj2OZK6d00Hiu6RrDY"
            : "pk_test_51HkpeZA0ee3CqG3OGCOsiZDvfeSYok5VPn37Cbbsp774FUbffvSIECmfdvZwCElKZAtQSAy7BgDd0147oopkLFp300bVptWPAe")
      };
    }
    if (applePayMerchantIdentifier != null) {
      args.addAll(<String, dynamic>{
        "applePayMerchantIdentifier": applePayMerchantIdentifier
      });
    }
    if (stripeAccount != null) {
      args.addAll(<String, dynamic>{"stripeAccount": stripeAccount});
    }
    await _channel.invokeMethod('setStripeSettings', args);
  }

  ///Present the Payment Collection Form
  static Future<PaymentResponse> addPaymentMethod() async {
    var response = await _channel.invokeMethod('addPaymentMethod');
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }

  ///Use to process immediate payments
  static Future<PaymentResponse> confirmPaymentIntent(
      String clientSecret, String stripePaymentMethodId, double amount,
      [bool isApplePay]) async {
    assert(clientSecret != null);
    assert(amount != null);
    assert(stripePaymentMethodId != null);

    final Map<String, Object> args = <String, dynamic>{
      "clientSecret": clientSecret,
      "paymentMethodId": stripePaymentMethodId,
      "amount": amount,
      "isApplePay": isApplePay ?? false
    };
    var response = await _channel.invokeMethod('confirmPaymentIntent', args);
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }

  ///Use to setup future payments
  static Future<PaymentResponse> setupPaymentIntent(
      String clientSecret, String stripePaymentMethodId,
      [bool isApplePay]) async {
    assert(clientSecret != null);
    assert(stripePaymentMethodId != null);
    final Map<String, Object> args = <String, dynamic>{
      "clientSecret": clientSecret,
      "paymentMethodId": stripePaymentMethodId,
      "isApplePay": isApplePay ?? false
    };
    var response = await _channel.invokeMethod('setupPaymentIntent', args);
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }
}

class PaymentResponse {
  PaymentResponseStatus status;
  String paymentIntentId;
  String paymentMethodId;
  String errorMessage;

  PaymentResponse.fromJson(Map json) {
    this.paymentIntentId = json["paymentIntentId"] as String;
    this.paymentMethodId = json["paymentMethodId"] as String;
    this.errorMessage = json["errorMessage"] as String;
    this.status =
        _$enumDecodeNullable(_$PaymentResponseStatusEnumMap, json['status']);
  }

  T _$enumDecodeNullable<T>(Map<T, dynamic> enumValues, dynamic source) {
    if (source == null) {
      return null;
    }
    return _$enumDecode<T>(enumValues, source);
  }

  T _$enumDecode<T>(Map<T, dynamic> enumValues, dynamic source) {
    if (source == null) {
      throw ArgumentError('A value must be provided. Supported values: '
          '${enumValues.values.join(', ')}');
    }
    return enumValues.entries
        .singleWhere((e) => e.value == source,
            orElse: () => throw ArgumentError(
                '`$source` is not one of the supported values: '
                '${enumValues.values.join(', ')}'))
        .key;
  }

  final _$PaymentResponseStatusEnumMap = <PaymentResponseStatus, dynamic>{
    PaymentResponseStatus.succeeded: 'succeeded',
    PaymentResponseStatus.failed: 'failed',
    PaymentResponseStatus.canceled: 'canceled'
  };
}

enum PaymentResponseStatus { succeeded, failed, canceled }

==> woosignal_stripe-1.1.0.tar.gz: lib/woosignal_stripe.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class FlutterStripePayment {
  static const MethodChannel _channel = const MethodChannel('woosignal_stripe');

  static Future<void> setStripeSettings(
      {String? applePayMerchantIdentifier,
      String? stripeAccount,
      bool? liveMode,
      bool? useShopifyGateway}) async {
    Map<String, dynamic> args = <String, dynamic>{
      "stripePublishableKey": (liveMode == true
          ? "pk_live_IyS4Vt86L49jITSfaUShumzi"
          : "pk_test_0jMmpBntJ6UkizPkfiB8ZJxH")
    };
    if (useShopifyGateway == true) {
      args = <String, dynamic>{
        "stripePublishableKey": (liveMode == true
            ? "pk_live_51HkpeZA0ee3CqG3ORUQuHfGW35nfCRi6SVP77RMjYu4IsWwRMjhHrNKrqD6Q47jETYLH3CtXqk4Px8SBVj2OZK6d00Hiu6RrDY"
            : "pk_test_51HkpeZA0ee3CqG3OGCOsiZDvfeSYok5VPn37Cbbsp774FUbffvSIECmfdvZwCElKZAtQSAy7BgDd0147oopkLFp300bVptWPAe")
      };
    }
    if (applePayMerchantIdentifier != null) {
      args.addAll(<String, dynamic>{
        "applePayMerchantIdentifier": applePayMerchantIdentifier
      });
    }
    if (stripeAccount != null) {
      args.addAll(<String, dynamic>{"stripeAccount": stripeAccount});
    }
    await _channel.invokeMethod('setStripeSettings', args);
  }

  ///Present the Payment Collection Form
  static Future<PaymentResponse> addPaymentMethod() async {
    var response = await _channel.invokeMethod('addPaymentMethod');
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }

  ///Use to process immediate payments
  static Future<PaymentResponse> confirmPaymentIntent(
      String clientSecret, String stripePaymentMethodId, double amount,
      [bool? isApplePay]) async {
    final Map<String, dynamic> args = <String, dynamic>{
      "clientSecret": clientSecret,
      "paymentMethodId": stripePaymentMethodId,
      "amount": amount,
      "isApplePay": isApplePay ?? false
    };
    var response = await _channel.invokeMethod('confirmPaymentIntent', args);
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }

  ///Use to setup future payments
  static Future<PaymentResponse> setupPaymentIntent(
      String clientSecret, String stripePaymentMethodId,
      [bool? isApplePay]) async {
    final Map<String, dynamic> args = <String, dynamic>{
      "clientSecret": clientSecret,
      "paymentMethodId": stripePaymentMethodId,
      "isApplePay": isApplePay ?? false
    };
    var response = await _channel.invokeMethod('setupPaymentIntent', args);
    var paymentResponse = PaymentResponse.fromJson(response);
    return paymentResponse;
  }
}

class PaymentResponse {
  PaymentResponseStatus? status;
  String? paymentIntentId;
  String? paymentMethodId;
  String? errorMessage;

  PaymentResponse.fromJson(Map json) {
    this.paymentIntentId = json["paymentIntentId"] as String?;
    this.paymentMethodId = json["paymentMethodId"] as String?;
    this.errorMessage = json["errorMessage"] as String?;
    this.status =
        _$enumDecodeNullable(_$PaymentResponseStatusEnumMap, json['status']);
  }

  T? _$enumDecodeNullable<T>(Map<T, dynamic> enumValues, dynamic source) {
    if (source == null) {
      return null;
    }
    return _$enumDecode<T>(enumValues, source);
  }

  T _$enumDecode<T>(Map<T, dynamic> enumValues, dynamic source) {
    if (source == null) {
      throw ArgumentError('A value must be provided. Supported values: '
          '${enumValues.values.join(', ')}');
    }
    return enumValues.entries
        .singleWhere((e) => e.value == source,
            orElse: (() => throw ArgumentError(
                '`$source` is not one of the supported values: '
                '${enumValues.values.join(', ')}')))
        .key;
  }

  final _$PaymentResponseStatusEnumMap = <PaymentResponseStatus, dynamic>{
    PaymentResponseStatus.succeeded: 'succeeded',
    PaymentResponseStatus.failed: 'failed',
    PaymentResponseStatus.canceled: 'canceled'
  };
}

enum PaymentResponseStatus { succeeded, failed, canceled }
